//
// Created by maassms on 20.08.15.
//

#ifndef WXLAUNCHER_COMPATIBILITY_H
#define WXLAUNCHER_COMPATIBILITY_H

#include "apis/ProfileManager.h"

namespace Compatibility
{
	bool SynchronizeOldPilots(ProMan* profileManager);

	bool MigrateOldConfig();
}

#endif //WXLAUNCHER_COMPATIBILITY_H
